@@ -44,22 +44,22 @@ class Utilities(object):
                           params=None,
                           expectedStatusCode=requests.codes.ok,
                           jsonPayload=None,
-                          token=None):
+                          token=None,envFile=None):
         if token!= None:
             headers = {'Content-Type': 'application/json',
                       'X-Zeta-AuthToken': token}
         elif user == "userAuthToken":
-            headers = functionalParm.getHeaderClearRateLImit(user)
+            headers = functionalParm.getHeaderClearRateLImit(user,envFile)
         elif user == "userStaticToken":
-            headers = functionalParm.getTokenCardApplication(user)
+            headers = functionalParm.getTokenCardApplication(user,envFile)
         elif user == "user3":
-            headers = header.createIDHeaders()
+            headers = header.createIDHeaders(envFile)
         elif user == "UpdateStatusUser":
-            headers = header.updateStatusHeaders()
+            headers = header.updateStatusHeaders(envFile)
         elif user == "ganymedeUser":
-            headers = header.ganymedeHeaders()
+            headers = header.ganymedeHeaders(envFile)
         elif user != 'null':
-            headers = functionalParm.getHeader(user)
+            headers = functionalParm.getHeader(user,envFile)
         else:
             headers = None
 
@@ -72,20 +72,23 @@ class Utilities(object):
         logger.info(response.json())
         return response
         pass
+        
+        
+        
     def check_status_code_no_response_body(self,
                           endPoint=None,
                           requestMethod="GET",
                           user="Captain_America",
                           params=None,
                           expectedStatusCode=requests.codes.ok,
-                          jsonPayload=None, token=None):
+                          jsonPayload=None, token=None,envFile=None):
         if token!= None:
             headers = {'Content-Type': 'application/json',
                       'X-Zeta-AuthToken': token}
         elif user == "userStaticToken":
-            headers = functionalParm.getTokenCardApplication(user)
+            headers = functionalParm.getTokenCardApplication(user,envFile)
         elif user != 'null':
-            headers = functionalParm.getHeader(user)
+            headers = functionalParm.getHeader(user,envFile)
         else:
             headers = None
 
@@ -99,6 +102,10 @@ class Utilities(object):
     def assert_error_message(self,response,errorKey,errorMessage):
         if response:
             assert response.json().get(errorKey) == errorMessage
+
+    def assert_error_message(self,response,errorKey,errorMessage):
+        if response:
+            assert response.json().get(errorKey) == errorMessage
         
         
     def check_status_code(self,
@@ -170,9 +177,9 @@ class Utilities(object):
             endPoint = endPoint.replace("ifi/151613", "ifi/13")
         response = requests.request(requestMethod, endPoint, headers=headers, params=params, json=jsonPayload)
         logger.info(f"status code{response.status_code}")
-        logger.info("--------CURL START---------")
-        functionalParm.curl_request(response.request.url,requestMethod,headers,jsonPayload)
-        logger.info("--------CURL END---------")
+        # logger.info("--------CURL START---------")
+        # functionalParm.curl_request(response.request.url,requestMethod,headers,jsonPayload)
+        # logger.info("--------CURL END---------")
         assert response.status_code == expectedStatusCode, \
             f"Expected Status Code {expectedStatusCode} and Actual status {response.status_code} code did not match with failure reason {response.json()}"
         return response
